@@ -31,7 +31,10 @@ class RebotaComoPelota(Habilidad):
                                        receptor.y + error, 
                                        receptor.radio_de_colision)
         receptor.aprender(pilas.habilidades.Imitar, circulo)
+        self.circulo = circulo
         
+    def eliminar(self):
+        self.circulo.eliminar()
 
 class RebotaComoCaja(Habilidad):
 
@@ -44,6 +47,10 @@ class RebotaComoCaja(Habilidad):
                                              receptor.radio_de_colision*2,
                                              )
         receptor.aprender(pilas.habilidades.Imitar, rectangulo)
+        self.rectangulo = rectangulo
+
+    def eliminar(self):
+        self.rectangulo.eliminar()
         
         
 class ColisionableComoPelota(RebotaComoPelota):
@@ -219,4 +226,4 @@ class Imitar(Habilidad):
     def actualizar(self):
         self.receptor.x = self.objeto_a_imitar.x
         self.receptor.y = self.objeto_a_imitar.y
-        self.receptor.rotacion = self.objeto_a_imitar.rotacion
\ No newline at end of file
+        self.receptor.rotacion = self.objeto_a_imitar.rotacion
