@@ -28,7 +28,7 @@ class Mundo:
     motor y mantener el bucle de juego.
     """
 
-    def __init__(self, ancho, alto, titulo, fps=60, economico=True):
+    def __init__(self, ancho, alto, titulo, fps=60, economico=True, gravedad=(0, -90)):
         self.ventana = ventana.iniciar(ancho, alto, titulo)
         self.fps = fps
         self.economico = economico
@@ -53,7 +53,7 @@ class Mundo:
         self.tasks = tareas.Tareas() 
         
         # Genera el motor de fisica.
-        self.fisica = pilas.fisica.Fisica()
+        self.fisica = pilas.fisica.Fisica(gravedad=gravedad)
         
         self.pausa_habilitada = False
         self.depuracion_fisica_habilitada = False
@@ -130,6 +130,7 @@ class Mundo:
     def definir_escena(self, escena_nueva):
         "Cambia la escena que se muestra en pantalla"
         self.escena_actual = escena_nueva
+	escena_nueva.iniciar()
 
     def agregar_tarea(self, time_out, function, *params): 
         self.tasks.agregar(time_out, function, params)
